#'Conversion of a imputed data set (long form) to a \code{mids} object
#'
#'Deprecated. Use \code{as.mids()} instead.
#'@aliases long2mids
#'@param x argument
#'@return An object of class \code{mids}
#'@author Stef van Buuren, 2012
#'@seealso \code{\link{as.mids}}
#'@keywords internal

long2mids <- function(x){
    cat("Deprecated. Use as.mids().\n")
}
